Module encode

Module encode 

Traits

PayloadRLPEncode
RLPEncode

Functions

bytes_length
Computes the length needed for a given byte-string and first byte
encode
Function for encoding a value to RLP. For encoding the value into a buffer directly, use RLPEncode::encode.
encode_length
list_length
Computes the length needed for a given payload length